@@ -1,6 +1,6 @@
 #  gcompris - board_list.py
 #
-# Copyright (C) 2005 Yves Combe
+# Copyright (C) 2005, 2008 Yves Combe
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 #   along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 
-import gnomecanvas
+import goocanvas
 import gcompris
 import gcompris.utils
 import gcompris.skin
@@ -26,9 +26,6 @@ import gtk.gdk
 import gobject
 from gcompris import gcompris_gettext as _
 
-# Database
-#from pysqlite2 import dbapi2 as sqlite
-
 # Board Management
 (
    COLUMN_BOARDICON,
@@ -40,11 +37,16 @@ class Board_list:
 
 
   # area is the drawing area for the list
-  def __init__(self, db_connect, db_cursor, frame):
+  def __init__(self, db_connect, db_cursor, frame, default_profile_id,
+          hide_profiles=False):
 
       self.frame = frame
       self.cur = db_cursor
       self.con = db_connect
+      self.default_profile_id = default_profile_id
+      self.hide_profiles = hide_profiles
+
+  def init(self):
 
       # ---------------
       # Boards Management
@@ -54,18 +56,13 @@ class Board_list:
       # Create the profiles Combo
       self.profiles_list = gcompris.admin.get_profiles_list()
 
-      # Get default pofile id.
-      self.cur.execute('SELECT profile_id FROM informations;')
-      self.con.commit()
-
-      self.default_profile_id = self.cur.fetchall()[0][0]
+      if not self.profiles_list:
+        return
 
       self.out_dict = self.get_boards_out_by_profile()
 
       self.difficulty = [1, 6]
 
-      #print out_dict
-
       # Main box is vertical
       top_box = gtk.VBox(False, 8)
       top_box.show()
@@ -80,8 +77,9 @@ class Board_list:
       box3 = gtk.VBox(False, 8)
       box3.show()
 
-      top_box.pack_start(box1, False, False, 0)
-      top_box.pack_start(box2, True, True, 0)
+      if not self.hide_profiles:
+        top_box.pack_start(box1, False, False, 0)
+      top_box.pack_end(box2, True, True, 0)
 
       box2.pack_end(box3, False, False, 0)
 
@@ -93,14 +91,19 @@ class Board_list:
       combobox.show()
       box1.pack_start(combobox, False, False, 0)
 
-      i = 0
       for profile in self.profiles_list:
         combobox.append_text(profile.name)
         if profile.profile_id == self.default_profile_id:
           combobox.set_active(self.profiles_list.index(profile))
 
-      self.active_profile = self.profiles_list[combobox.get_active()]
-      print 'Active profile is now', self.active_profile.name
+      self.active_profile = filter(lambda x:
+              x.profile_id == self.default_profile_id, self.profiles_list)[0]
+
+      self.progressbar_box = gtk.Alignment(0.5, 0.5, 0.5, 0)
+      self.progressbar = gtk.ProgressBar(adjustment=None)
+      self.progressbar.show();
+      self.progressbar_box.add(self.progressbar)
+      box2.pack_start(self.progressbar_box)
 
       # Create the table
       sw = gtk.ScrolledWindow()
@@ -172,6 +175,14 @@ class Board_list:
       box3.pack_end(self.button_login, False, False, 0)
 
 
+  def show(self, db_connect, db_cursor):
+    self.cur = db_cursor
+    self.con = db_connect
+    self.frame.show()
+
+  def hide(self):
+    self.frame.hide()
+
   # -------------------
   # Board Management
   # -------------------
@@ -216,14 +227,20 @@ class Board_list:
     self.board_dict = {}
     height = 24
 
+    self.progressbar_box.show()
+    index = 0.0
     for board_cell in menu_list:
       self.board_dict['%s/%s' % (board_cell[1].section,board_cell[1].name)] = board_cell[1]
 
+      self.progressbar.set_fraction(index / len(menu_list))
+      index = index + 1
+      while gtk.events_pending():
+        gtk.main_iteration(False)
 
       if  board_cell[0] == None:
         row_dict[''] =  \
                      model.append(None,
-                                  [self.pixbuf_at_height('gcompris/misc/tuxplane.png', height),
+                                  [self.pixbuf_admin_at_height('administration/tuxplane.svg', height),
                                    _('Main menu') + '\n' + '/',
                                    not board_cell[1].board_id in self.out_dict[self.active_profile.profile_id],
                                    '%s/%s' % (board_cell[1].section,board_cell[1].name), self.pixbuf_configurable(board_cell[1])])
@@ -231,18 +248,17 @@ class Board_list:
       else:
         row_dict['%s/%s' % (board_cell[1].section,board_cell[1].name)] = \
                          model.append(row_dict[board_cell[1].section],
-                                      [self.pixbuf_skin_at_height(board_cell[1].icon_name, height),
+                                      [self.pixbuf_at_height(board_cell[1].icon_name, height),
                                        _(board_cell[1].title) + '\n' + '%s/%s' % (board_cell[1].section,board_cell[1].name),
                                        not board_cell[1].board_id in self.out_dict[self.active_profile.profile_id],
                                        '%s/%s' % (board_cell[1].section,board_cell[1].name), self.pixbuf_configurable(board_cell[1])])
+    self.progressbar_box.hide()
 
-
-  def pixbuf_skin_at_height(self, file, height):
-    pixbuf = gcompris.skin.load_pixmap(file)
+  def pixbuf_admin_at_height(self, file, height):
+    pixbuf = gcompris.utils.load_pixmap(file)
     width = pixbuf.get_width()* height / pixbuf.get_height()
     del pixbuf
-    pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(gcompris.DATA_DIR + '/' +
-                                                  gcompris.skin.image_to_skin(file),
+    pixbuf = gtk.gdk.pixbuf_new_from_file_at_size(gcompris.DATA_DIR + '/' + file,
                                                   width, height)
     return pixbuf
 
@@ -322,12 +338,13 @@ class Board_list:
       pass
 
     self.update_selected(model, path)
+    self.con.commit()
 
   def update_selected(self, model, path):
     if model[path][2]:
       self.cur.execute('DELETE FROM activities_out WHERE board_id=%d AND out_id=%d' % (
         self.board_dict[model[path][3]].board_id,
-                                                                                       self.active_profile.profile_id
+        self.active_profile.profile_id
         ))
     else:
       self.cur.execute('INSERT INTO activities_out (board_id, out_id) VALUES (%d, %d)' % (
@@ -335,8 +352,6 @@ class Board_list:
         self.active_profile.profile_id
         ))
 
-    self.con.commit()
-
     # update infos
     self.out_dict = self.get_boards_out_by_profile()
 
@@ -359,8 +374,6 @@ class Board_list:
       return
     self.active_profile = self.profiles_list[index]
 
-    print 'Active profile is now', self.active_profile.name
-
     self.model.foreach(self.update_active)
 
   def update_active(self, model, path, iter):
@@ -379,13 +392,12 @@ class Board_list:
       return None
 
   def preference_clicked(self, widget, event, board):
-    print 'preference', board.title
+    pass
 
   def row_selected(self, treeview,  model):
     if treeview.get_selection().count_selected_rows() != 1:
       return
     path = model.get_path(treeview.get_selection().get_selected()[1])
-    print "Row selected:", model[path][3]
 
     self.selected_board = self.board_dict[model[path][3]]
     if self.selected_board.is_configurable:
@@ -396,11 +408,10 @@ class Board_list:
   def configure_board(self, button):
     gcompris.admin.board_config_start(self.selected_board,
                                       self.active_profile)
-    #unused
-    #gcompris.admin.board_config_stop(self.selected_board)
 
   def select_all_boards(self, button, Value):
     self.model.foreach(self.update_all, Value)
+    self.con.commit()
 
   def update_all(self, model, path, iter, Value):
     model[path][2] = Value
@@ -462,7 +473,7 @@ class Board_list:
       box.show()
       symbols_box.pack_start(box, True, False, 0)
       self.stars[i] = gtk.Image()
-      self.stars[i].set_from_pixbuf(gcompris.skin.load_pixmap('difficulty_star%d.png' % (i)))
+      self.stars[i].set_from_pixbuf(gcompris.utils.load_pixmap('administration/difficulty%d.svg' % (i)))
       self.stars[i].show()
       box.pack_start(self.stars[i], False, False, 0)
       i_label = gtk.Label()
@@ -553,6 +564,7 @@ class Board_list:
   def filter_apply(self, button):
     self.model.foreach(self.blank)
     self.model.foreach(self.board_filter)
+    self.con.commit()
 
   # Apply the filter as asked.
   def board_filter(self,  model, path, iter):
@@ -561,8 +573,6 @@ class Board_list:
                          in range( self.difficulty[0],
                                    self.difficulty[1]+1))
 
-    print self.board_dict[model[path][3]].name, self.board_dict[model[path][3]].difficulty, self.difficulty, model[path][2]
-
     if model[path][2]:
       self.update_parent(model[path].parent)
 
@@ -631,44 +641,37 @@ class Board_list:
 
   def locales(self, button):
     conf_locales = self.get_configured(self.active_profile, 'locale', 'NULL')
-    self.main_vbox = gcompris.configuration_window ( \
-      _('<b>%s</b> configuration\n for profile <b>%s</b>') % ('Locale', self.active_profile.name ),
+    # Translators : Do not translate the token {profile}
+    bconf = gcompris.configuration_window ( \
+      _('<b>Locale</b> configuration\n for profile <b>{profile}</b>').\
+        format(profile=self.active_profile.name),
       self.ok_callback
       )
 
-    label = gtk.Label()
-    label.set_line_wrap(True)
-    label.set_markup('Choose the default locale used by localizable boards for profile %s' % self.active_profile.name)
-    label.show()
-    self.main_vbox.pack_start (label, False, False, 8)
-
-    gcompris.separator()
-
-    gcompris.combo_locales( conf_locales)
+    gcompris.combo_locales(bconf, conf_locales)
 
   def locales_sound(self, button):
 
-    conf_locales = self.get_configured(self.active_profile, 'locale_sound', 'NULL')
-    self.main_vbox = gcompris.configuration_window ( \
-      _('<b>%s</b> configuration\n for profile <b>%s</b>') % ('Locale sound', self.active_profile.name ),
+    conf_locales = self.get_configured(self.active_profile,
+                                       'locale_sound', 'NULL')
+    # Translators : Do not translate the token {profile}
+    bconf = gcompris.configuration_window ( \
+      _('<b>Locale sound</b> configuration\n for profile <b>{profile}</b>').\
+        format(profile=self.active_profile.name),
       self.ok_callback
       )
 
-    label = gtk.Label()
-    label.set_line_wrap(True)
-    label.set_markup('Choose the default locale for <b>sounds</b> used by localizable boards for profile %s' % self.active_profile.name)
-    label.show()
-    self.main_vbox.pack_start (label, False, False, 8)
-
-    gcompris.separator()
-
-    gcompris.combo_locales_asset( _("Select sound locale"),
+    gcompris.combo_locales_asset( bconf,
+                                  _("Select sound locale"),
                                   conf_locales,
-                                  "voices/$LOCALE/colors/purple.ogg" )
+                                  "voices/$LOCALE/colors/red.ogg" )
 
 
   def ok_callback(self, dict):
 
+    if not dict:
+      return
+
     for key, value in dict.iteritems():
       if key in self.already_conf:
         req = 'UPDATE board_profile_conf SET conf_value=\'%s\' WHERE profile_id=%d AND board_id=-1 AND conf_key=\'%s\'' % (value, self.active_profile.profile_id, key)
@@ -679,7 +682,8 @@ class Board_list:
       self.con.commit()
 
   def get_configured(self, profile, key, if_not):
-    self.cur.execute('select conf_value from board_profile_conf where profile_id=%d and board_id=-1 and conf_key =\'%s\' ' % (profile.profile_id, key))
+    self.cur.execute('select conf_value from board_profile_conf where profile_id=%d and board_id=-1 and conf_key =\'%s\' '
+                     % (profile.profile_id, key))
 
     value = self.cur.fetchall()
 
@@ -696,14 +700,7 @@ class Board_list:
 
 
   def login_configure(self, button):
-    print "__login configure__"
+
     board_log = self.get_board_by_name('/login/login', self.boards_list)
-    print board_log.name, board_log.is_configurable
-    gcompris.admin.board_config_start(board_log,
-                                      self.active_profile)
+    gcompris.admin.board_config_start(board_log, self.active_profile)
 
-
-
-  def wordlist(self, button):
-    import wordlist
-    wordlist.Words_list(self.con, self.cur, self.active_profile)
