@@ -1,6 +1,6 @@
 #  gcompris - class_edit.py
 #
-# Copyright (C) 2005 Bruno Coudoin and Yves Combe
+# Copyright (C) 2005, 2008 Bruno Coudoin and Yves Combe
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -19,12 +19,8 @@
 
 import gtk
 import gobject
-import gcompris
 from gcompris import gcompris_gettext as _
 
-# Database
-from pysqlite2 import dbapi2 as sqlite
-
 import user_list
 
 import constants
@@ -186,9 +182,6 @@ class ClassEdit(gtk.Window):
 
         bbox = gtk.HBox(homogeneous=False, spacing=8)
 
-        button = gtk.Button(stock='gtk-help')
-        bbox.pack_start(button, expand=False, fill=False, padding=0)
-
         button = gtk.Button(stock='gtk-ok')
         bbox.pack_end(button, expand=False, fill=False, padding=0)
         button.connect("clicked", self.ok)
@@ -221,12 +214,12 @@ class ClassEdit(gtk.Window):
                    )
 
     # If class_id is provided, only users in this class are inserted
-    # If with = True, create a list only with the given class_id.
+    # If gwith = True, create a list only with the given class_id.
     #           False, create a list only without the given class_id
-    def __create_model(self, _with, class_id):
+    def __create_model(self, gwith, class_id):
 
         # Grab the user data
-        if(_with):
+        if(gwith):
             self.cur.execute('SELECT user_id,firstname,lastname FROM users where class_id=? ORDER BY login', (class_id,))
         else:
             self.cur.execute('SELECT user_id,firstname,lastname FROM users WHERE class_id!=? ORDER BY login', (class_id,))
@@ -295,7 +288,6 @@ class ClassEdit(gtk.Window):
             self.cur.execute('UPDATE users SET class_id=? WHERE user_id=?',
                              (self.class_id, user_id))
             self.con.commit()
-            print "UPDATE users SET class_id=%d" %self.class_id
 
     # Remove a user from the right list to the left list
     #
@@ -318,7 +310,6 @@ class ClassEdit(gtk.Window):
             # Save the change in the base (1 Is the 'Unselected user' class)
             self.cur.execute('UPDATE users SET class_id=? where user_id=?', (1, user_id))
             self.con.commit()
-            print "UPDATE users SET class_id=1"
 
     # Done, can quit this dialog (without saving)
     #
@@ -347,9 +338,12 @@ class ClassEdit(gtk.Window):
         # Now everything is correct, create the class
         #
 
+        self.class_name   = unicode(self.entry_class.get_text())
+        self.teacher_name = unicode(self.entry_teacher.get_text())
+
         class_data = (self.class_id,
-                      self.entry_class.get_text(),
-                      self.entry_teacher.get_text()
+                      self.class_name,
+                      self.teacher_name
                       )
 
         if(self.new_class):
@@ -357,17 +351,13 @@ class ClassEdit(gtk.Window):
 
         # Save the changes in the base
         self.cur.execute('UPDATE class set name=?,teacher=? where class_id=?',
-                         (self.entry_class.get_text(),
-                          self.entry_teacher.get_text(),
+                         (self.class_name,
+                          self.teacher_name,
                           self.class_id));
         self.con.commit()
 
         # Close the dialog window now
         # (The close code will refresh the class_list)
-        self.class_name   = self.entry_class.get_text()
-        self.teacher_name = self.entry_teacher.get_text()
-
-        print "class_edit done"
         self.destroy()
 
 
@@ -379,7 +369,7 @@ class ClassEdit(gtk.Window):
 
         # Check the login do not exist already
         self.cur.execute('SELECT name FROM class WHERE name=?',
-                         (self.entry_class.get_text(),))
+                         (unicode(self.entry_class.get_text()),))
         if(self.cur.fetchone()):
             dialog = gtk.MessageDialog(None,
                                        gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
@@ -396,8 +386,8 @@ class ClassEdit(gtk.Window):
                          (group_id, self.class_id));
 
         class_data = (self.class_id,
-                      self.entry_class.get_text(),
-                      self.entry_teacher.get_text(),
+                      unicode(self.entry_class.get_text()),
+                      unicode(self.entry_teacher.get_text()),
                       group_id
                       )
 
