@@ -66,25 +66,35 @@ class Gcompris_findit:
       if not data:
         return
 
+      if self.gcomprisBoard.mode == "nobackgroundmusic":
+        # pause the bg music
+        gcompris.sound.pause()
+
       self.gcomprisBoard.level = 1
       self.gcomprisBoard.maxlevel = self.dataset.number_of_level()
       self.gcomprisBoard.sublevel = 1;
       gcompris.bar_set(gcompris.BAR_LEVEL|gcompris.BAR_REPEAT)
       gcompris.bar_set_level(self.gcomprisBoard)
       gcompris.sound.policy_set(gcompris.sound.PLAY_AND_INTERRUPT)
+      self.first_run = True
       self.play(data)
 
-
   def end(self):
     # Remove the root item removes all the others inside it
     if self.rootitem:
       self.rootitem.remove()
       self.rootitem = None
 
+      if self.gcomprisBoard.mode == "nobackgroundmusic":
+        gcompris.sound.resume()
+
   def repeat(self):
     self.play_audio_question(self.datasetlevel.question_audio, self.object_target)
 
 
+  def key_press(self, keyval, commit_str, preedit_str):
+    pass
+
   def pause(self, pause):
     self.board_paused = pause
 
@@ -211,17 +221,35 @@ class Gcompris_findit:
 
     self.datasetlevel.sort_objects()
     self.object_target = self.get_next_question()
+
+    if not self.first_run:
+      self.display_question(self.datasetlevel, self.object_target)
+    else:
+      text, rect = textBox(_('I am Ready'), 400, 250, self.rootitem,
+                           fill_color_rgba = 0x666666CCL,
+                           stroke_color_rgba = 0x000000FFL)
+      gcompris.utils.item_focus_init(rect, None)
+      rect.connect("button_press_event", self.first_run_event, text, rect)
+
+  def first_run_event(self, widget, target, event, text, rect):
+    self.first_run = False
+    text.remove()
+    gcompris.utils.item_focus_remove(rect, None)
+    rect.remove()
     self.display_question(self.datasetlevel, self.object_target)
 
   def play_audio_question(self, question, object_):
     # Play the audio question if provided
     audio = question
-    try:
-      # The question audio can be formatted with {text} and if so this
-      # is replaced by the target text
-      audio = audio.format(text = object_.text)
-    except:
-      pass
+    if audio:
+      try:
+        # The question audio can be formatted with {text} and if so this
+        # is replaced by the target text
+        audio = audio.format(text = object_.text)
+      except:
+        pass
+    else:
+      audio = object_.audio
 
     try:
       # The question audio can be formatted with {audio} and if so this
@@ -252,12 +280,15 @@ class Gcompris_findit:
   def display_question(self, datasetlevel, object_target):
     # The question
     text = datasetlevel.question_text
-    try:
-      # The question can be formatted with {text} and if so this
-      # is replaced by the target name
-      text = _(text.format(text = _(object_target.text)))
-    except:
-      pass
+    if text:
+      try:
+        # The question can be formatted with {text} and if so this
+        # is replaced by the target name
+        text = _(text.format(text = _(object_target.text)))
+      except:
+        pass
+    else:
+      text = _(object_target.text)
 
     try:
       # The question can be formatted with {audio} and if so this
@@ -273,13 +304,16 @@ class Gcompris_findit:
     self.play_audio_question(datasetlevel.question_audio, object_target)
 
   def ok_event(self, widget, target, event, dummy):
+    if self.first_run:
+      return
+
     if self.selected:
       if (self.selected.text == self.object_target.text):
-        print "WON " + self.selected.text
+        #print "WON " + self.selected.text
         self.gamewon = 1
         gcompris.bonus.display(gcompris.bonus.WIN, gcompris.bonus.FLOWER)
       else:
-        print "LOST: " +  self.selected.text + " != " + self.object_target.text
+        #print "LOST: " +  self.selected.text + " != " + self.object_target.text
         if not self.object_target in self.question_lost:
           self.question_lost.append( self.object_target )
         self.gamewon = 0
@@ -287,17 +321,15 @@ class Gcompris_findit:
 
   #
   def item_event(self, item, target, event, object_source):
+    if self.first_run:
+      return
+
     if self.selected:
       self.selected.select(False)
     self.selected = object_source
     self.selected.select(True)
     self.play_audio_question(object_source.audio, object_source)
 
-    if (object_source.text == self.object_target.text):
-      print "WON " + object_source.text
-    else:
-      print "LOST: " + object_source.text + " != " + self.object_target.text
-
   def read_data(self):
     '''Load the activity data, return True if OK'''
     config = ConfigParser.RawConfigParser()
@@ -311,7 +343,7 @@ class Gcompris_findit:
                                 format(filename=filename),
                               None)
         return False
-    except ConfigParser.Error as error:
+    except ConfigParser.Error, error:
       gcompris.utils.dialog(_("Failed to parse data set '{filename}'"
                               " with error:\n{error}").\
                               format(filename=filename, error=error),
@@ -334,7 +366,7 @@ class finditDataSet:
     for section in dataset.sections():
       if section == 'common': continue
       level = self._level(section)
-      print "processing level " + str(level)
+      #print "processing level " + str(level)
       if not level in self.levels:
         self.levels[level] = []
       self.levels[level].append( finditDataSetLevel(dataset, section) )
@@ -409,13 +441,13 @@ class finditDataSetLevel:
             load_common_prop(dataset, section, "questionPosition", "").split(','))
 
     try:
-      self.question_text = _( load_common_prop(dataset, section, "questionText", "") )
+      self.question_text = _( load_common_prop(dataset, section, "questionText", None) )
     except:
       self.question_text = None
 
-    print "     finditDataSetLevel " + self.question_text
+    #print "     finditDataSetLevel " + self.question_text
     try:
-      self.question_audio = load_common_prop(dataset, section, "questionAudio", "")
+      self.question_audio = load_common_prop(dataset, section, "questionAudio", None)
     except:
       self.question_audio = None
 
@@ -430,15 +462,13 @@ class finditDataSetLevel:
 
     i = 1
     self.objects = []
-    while True:
+    while dataset.has_option(section, "object" + str(i) + "Image"):
       try:
         dataset.get(section, "object" + str(i) + "Image")
         self.objects.append(finditDataSetObject(dataset, section, i))
-      except Exception as inst:
-        print type(inst)     # the exception instance
-        print inst.args
-        print inst
-        break
+      except:
+        # Should not happens
+        pass
       i += 1
     # Shuffle the object
     self.sort_objects()
@@ -478,16 +508,14 @@ class finditDataSetObject:
     self.selection = None
     # Some random key to allow the sorting
     self.randint = 0
-    print "     finditDataSetObject " + self.text
 
   def init_randint(self):
     self.randint = random.randint(0, 100)
 
   def _load_prop(self, dataset, level, index, suffix):
-    try:
+    if dataset.has_option(level, "object" + str(index) + suffix):
       return dataset.get(level, "object" + str(index) + suffix)
-    except:
-      return None
+    return None
 
   def create_item(self, rootitem, board_name, x, y):
     filename = gcompris.DATA_DIR + '/' \
@@ -552,11 +580,47 @@ class finditDataSetObject:
 # Load the requested property_ first from the level section
 # then from the common section if not found.
 def load_common_prop(dataset, level, property_, default):
-  try:
+  if dataset.has_option(level, property_):
     return dataset.get(level, property_)
-  except:
-    try:
-      return dataset.get("common", property_)
-    except:
-      return default
 
+  if dataset.has_option("common", property_):
+      return dataset.get("common", property_)
+
+  return default
+
+def textBox(text, x, y , rootitem, width=10000,
+            fill_color_rgba = None, stroke_color_rgba = None,
+            noRect=False, text_color="black"):
+    '''
+    write a textbox with text to the screen.
+    '''
+    text = goocanvas.Text(
+        parent = rootitem,
+        x=x,
+        y=y,
+        width=width,
+        text=text,
+        font = gcompris.skin.get_font("gcompris/board/big bold"),
+        fill_color=text_color,
+        anchor=gtk.ANCHOR_CENTER,
+        alignment=pango.ALIGN_CENTER,
+        pointer_events="GOO_CANVAS_EVENTS_NONE"
+        )
+    TG = 50
+    bounds = text.get_bounds()
+    if not noRect:
+        rect = goocanvas.Rect(parent = rootitem,
+                              x=bounds.x1 - TG,
+                              y=bounds.y1 - TG,
+                              width=bounds.x2 - bounds.x1 + TG * 2,
+                              height=bounds.y2 - bounds.y1 + TG * 2,
+                              line_width=3.0,
+                              radius_x = 5, radius_y = 5
+                              )
+        if fill_color_rgba:
+            rect.props.fill_color_rgba = fill_color_rgba
+        if stroke_color_rgba:
+            rect.props.stroke_color_rgba = stroke_color_rgba
+        text.raise_(rect)
+        return text, rect
+    return text
